@@ -7,11 +7,11 @@ package JE;
 # Note also that comments like "# E 7.1" refer to the indicated
 # clause (7.1 in this case) in the ECMA-262 standard.
 
-use 5.008004;
+use 5.008003;
 use strict;
 use warnings; no warnings 'utf8';
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 use Carp 'croak';
 use JE::Code 'add_line_number';
@@ -29,15 +29,13 @@ require JE::Scope                             ;
 require JE::String                          ;
 require JE::Undefined                     ;
 
-=encoding UTF-8
-
 =head1 NAME
 
 JE - Pure-Perl ECMAScript (JavaScript) Engine
 
 =head1 VERSION
 
-Version 0.066 (alpha release)
+Version 0.54 (alpha release)
 
 The API is still subject to change. If you have the time and the interest, 
 please experiment with this module (or even lend a hand :-).
@@ -98,6 +96,11 @@ Easy to install (no C compiler necessary*)
 
 =item -
 
+Compatible with L<Data::Dump::Streamer>, so the runtime environment
+can be serialised
+
+=item -
+
 The parser can be extended/customised to support extra (or
 fewer) language features (not yet complete)
 
@@ -106,18 +109,10 @@ fewer) language features (not yet complete)
 All JavaScript datatypes can be manipulated directly from Perl (they all
 have overloaded operators)
 
-=item -
-
-The JavaScript datatypes provide C<TO_JSON> methods for compatibility with
-L<JSON.pm|JSON>.
-
 =back
 
-JE's greatest weakness is that it's slow (well, what did you expect?).  It
-also uses and leaks lots of memory.  (There is an experimental
-L<JE::Destroyer (q.v.)|JE::Destroyer> module that solves this if you load
-it first and then call C<JE::Destroyer::destroy($j)> on the JE object when
-you have finished with it.)
+JE's greatest weakness is that it's slow (well, what did you expect?). It
+also uses and leaks lots of memory, but that will be fixed.
 
 * If you are using perl 5.9.3 or lower, then L<Tie::RefHash::Weak> is
 required. Recent versions of it require L<Variable::Magic>, an XS module
@@ -239,11 +234,11 @@ sub new {
 				#scope => bless [global], JE::Scope
 				func_name => 'Object',
 				func_argnames => [],
-				func_args => ['global','args'],
+				func_args => ['scope','args'],
 				function => sub { # E 15.2.1
 					return JE::Object->new( @_ );
 				},
-				constructor_args => ['global','args'],
+				constructor_args => ['scope','args'],
 				constructor => sub {
 					return JE::Object->new( @_ );
 				},
@@ -339,10 +334,6 @@ sub new {
 	);
 	$func_proto->prop({name=>'length', value=>0, dontenum=>1});
 
-	if($JE::Destroyer) {
-		JE::Destroyer'register($_) for $obj_constr, $func_constr;
-	}
-
 	# Before we add anything else, we need to make sure that our global
 	# true/false/undefined/null values are available.
 	@{$$self}{qw{ t f u n }} = (
@@ -1010,8 +1001,6 @@ sub false { $${+shift}{f} }
 (This method can create a potential security hole. Please see L</BUGS>,
 below.)
 
-=back
-
 =head2 Synopsis
 
  $j->bind_class(
@@ -2041,7 +2030,7 @@ sub bind_class {
 	return # nothing
 }
 
-=over
+
 
 =item $j->new_parser
 
@@ -2132,8 +2121,6 @@ The spec. states that, whenever it (the spec.), say to throw a
 SyntaxError, an implementation may provide other behaviour instead. Here
 are some instances of this:
 
-=over
-
 =item *
 
 C<return> may be used outside a function. It's like an 'exit' statement,
@@ -2322,9 +2309,20 @@ A Perl subroutine called from JavaScript can sneak past a C<finally> block and a
 
 =item *
 
-NaN and Infinity do not work properly on some Windows compilers.  32-bit
-ActivePerl seems not to work, but I have been told 64-bit is OK.
-Strawberry Perl works fine, which is what most people are using.
+NaN and Infinity do not work properly on some Windows compilers. I know
+that ActivePerl 5.8.6 doesn't work. (I do not know about later versions.)
+Strawberry Perl works fine, though, which is what most people are using.
+
+=back
+
+=head2 perl Incompatibilities
+
+=over 4
+
+=item *
+
+Invalid regular expression flags cause irrepressible warnings in perl 
+5.8.3.
 
 =back
 
@@ -2364,7 +2362,7 @@ to step 4.'
 The C<setTime> method of a Date object does what one would expect (it sets
 the number of milliseconds stored in the Date object and returns that
 number).
-According to the obfuscated definition in the ECMAScript specification, it 
+According the obfuscated definition in the ECMAScript specification, it 
 should always set it to NaN and return NaN.
 
 I think I've found I<yet another> typo in the spec. In clause 15.9.5.27,
@@ -2375,7 +2373,7 @@ I think I've found I<yet another> typo in the spec. In clause 15.9.5.27,
 
 =head1 PREREQUISITES
 
-perl 5.8.4 or higher
+perl 5.8.3 or higher
 
 Scalar::Util 1.14 or higher
 
@@ -2393,7 +2391,7 @@ the list of dependencies.
 
 =head1 AUTHOR, COPYRIGHT & LICENSE
 
-Copyright (C) 2007-14 Father Chrysostomos <sprout [at] cpan
+Copyright (C) 2007-11 Father Chrysostomos <sprout [at] cpan
 [dot] org>
 
 This program is free software; you may redistribute it and/or modify
@@ -2406,12 +2404,16 @@ Some of the code was derived from L<Data::Float>, which is copyrighted (C)
 
 Some of the
 
-Thanks to Max Maischein, Kevin Cameron, Chia-liang Kao and Damyan Ivanov
-for their
+Thanks to Kevin Cameron and Chia-liang Kao for their
 contributions,
 
-to Andy Armstrong, Yair Lenga, Alex Robinson, Christian Forster, Imre Rad,
-Craig Mackenna and Toby Inkster
+to Max Maischein for 
+letting
+me use
+his tests,
+
+to Andy Armstrong, Yair Lenga, Alex Robinson, Christian Forster, Imre Rad
+and Craig Mackenna
 for their suggestions,
 
 and to the CPAN Testers for their helpful reports.
@@ -2423,8 +2425,6 @@ the L<JE::Types> page):
 
 =over 4
 
-=item L<JE::Destroyer>
-
 =item L<JE::Types>
 
 =item L<JE::Object>
