@@ -1,6 +1,6 @@
 package JE::Boolean;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 
 use strict;
@@ -49,7 +49,6 @@ sub method {
 
 
 sub value { warn caller if !ref $_[0];shift->[0] }
-sub TO_JSON { \(0+shift->[0]) }
 
 sub exists { !1 }
 
@@ -113,5 +112,3 @@ The stringification and boolean operators are overloaded.
 =item L<JE::Types>
 
 =item L<JE::Object::Boolean>
-
-=back
