@@ -1,6 +1,6 @@
 package JE::Null;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 
 use strict;
@@ -50,7 +50,6 @@ Null stringifies to 'null', numifies to 0, and is false as a boolean.
 #use Carp;
 sub new    { bless \do{my $thing = $_[1]}, $_[0] }
 sub value  { undef }
-*TO_JSON=*value;
 sub typeof { 'object' }
 sub id     { 'null' }
 sub primitive { 1 }
@@ -74,8 +73,6 @@ sub global { ${$_[0]} }
 
 =item JE::Undefined
 
-=back
-
 =cut
 
 
