@@ -1,6 +1,6 @@
 package JE::Number;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 use strict;
 use warnings; no warnings 'utf8';
@@ -119,7 +119,6 @@ sub method {
 sub value {
 	shift->[0]
 }
-*TO_JSON=*value;
 
 sub exists { !1 }
 
@@ -232,8 +231,6 @@ The C<typeof> and C<class> methods produce the strings 'number' and
 
 =item L<JE::Object::Number>
 
-=back
-
 =cut
 
 
