@@ -1,6 +1,6 @@
 package JE::Object::Array;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 use strict;
 use warnings; no warnings 'utf8';
@@ -191,7 +191,6 @@ object, use C<@$a>.
 =cut
 
 sub value { [@{$${+shift}{array}}] };
-*TO_JSON=*value;
 
 
 sub exists {
@@ -221,10 +220,10 @@ sub _new_constructor {
 		name            => 'Array',
 		scope            => $global,
 		function         => $construct_cref,
-		function_args    => ['global','args'],
+		function_args    => ['scope','args'],
 		length           => 1,
 		constructor      => $construct_cref,
-		constructor_args => ['global','args'],
+		constructor_args => ['scope','args'],
 	});
 
 	my $proto = $f->prop({
