@@ -1,6 +1,6 @@
 package JE::Object::Math;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 
 use strict;
@@ -375,13 +375,6 @@ $y == 0 &&
 
 $x == 0 && $y < 0 && return JE'Number->new($global, inf);
 
-$x == -+inf && $y < 0 &&
-	return JE'Number->new($global,
-	                      int $y != $y || !($y % 2) ? 0 : -0.0);
-
-$x == -+inf && $y > 0 && int $y != $y &&
-	return JE'Number->new($global, inf);
-
 return JE::Number->new($global, $x ** $y);
 
 			},
@@ -517,6 +510,4 @@ return "a true value";
 
 =item JE::Number
 
-=back
-
 =cut
