@@ -1,6 +1,6 @@
 package JE::Object::RegExp;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 
 use strict;
@@ -9,17 +9,6 @@ use warnings; no warnings 'utf8';
 use overload fallback => 1,
 	'""'=> 'value';
 
-# This constant is true if we need to work around perl bug #122460 to keep
-# the ‘aardvark’ tests (in t/15.05-string-objects.t) passing.  This only
-# applies  to  perl  5.20.0.  (perl  5.20.1  includes  a  fix.)  Basic-
-# ally,  (?=...)  can result in buggy optimisations that cause  a  faulty
-# rejection of the match at some locations, because it is assumed that it
-# cannot match in some spots.
-use constant aardvark_bug =>
- # This test should match the empty string.  If it advances (pos returns
- # true), then we have the bug.
- do { my $a = "rdvark"; $a =~ /(?{})(?=.)a*?/g; pos $a };
-
 use Scalar::Util 'blessed';
 
 our @ISA = 'JE::Object';
@@ -324,12 +313,7 @@ sub new {
 	$self->prop({
 		name => source =>
 		# ~~~ Can we use ->_new here?
-		value  => JE::String->new($global, do {
-			(my $tmp = $re) =~
-				s<(\\.)|/>
-				<defined $1 ? $1 : '\/'>egg;
-			$tmp
-		}),
+		value  => JE::String->new($global, $re),
 		dontenum => 1,
 		readonly  => 1,
 		dontdel   => 1,
@@ -373,8 +357,7 @@ sub new {
 	# tioned above.
 
 	use constant 1.03 # multiple
-	{ # Make sure any changes to these constants are also
-	  # made at  the  end
+	{ # Make any changes to these constants are also made at the end
 	  # of the subroutine
 		# array indices within each item on the @stack:
 		posi => 0, # position within $new_re where the current
@@ -418,8 +401,6 @@ sub new {
 				  |
 				\\([1-9][0-9]*)
 				  |
-				\\?([\x{d800}-\x{dfff}])
-				  |
 				(\\(?:[^c]|c.))
 			/
 			  defined $1
@@ -434,9 +415,7 @@ sub new {
 			    defined $3 ? "\\x{$3}"      :
 			    defined $4 ? "(?(?{defined\$$4&&"
 			                ."!\$EraseCapture[$4]})\\$4)" :
-			    # work around a bug in perl:
-			    defined $5 ? sprintf '\\x{%x}', ord $5 :
-			    $6
+			    $5
 			/egxs;
 			$new_re .= $sub_pat;
 		}
@@ -460,8 +439,6 @@ sub new {
 				    |
 				  \\u([A-Fa-f0-9]{4})
 				    |
-				  \\?([\x{d800}-\x{dfff}])
-				    |
 				  (\\(?:[^c]|c.))
 				/
 			  	  defined $1 ? $_class_patterns{$1} :
@@ -472,9 +449,7 @@ sub new {
 				  defined $5 ? ((push @full_classes,
 					$_patterns{$5}),'') :
 				  defined $6 ? "\\x{$6}"  :
-				  # work around a bug in perl:
-				  defined $7 ? sprintf '\\x{%x}', ord $7 :
-			    	  $8
+			    	  $7
 				/egxs;
 
 				$new_re .= length $sub_pat
@@ -622,8 +597,9 @@ sub new {
 	@stack or die new JE::Object::Error::SyntaxError $global,
 		add_line_number "Unmatched ) in regexp";
 
-	aardvark_bug && $new_re =~ /\(\?=/
-	 and substr $new_re,0,0, = '(??{""})';
+
+	# This substitution is a workaround for a bug in perl.
+	$new_re =~ s/([\x{d800}-\x{dfff}])/sprintf '\\x{%x}', ord $1/ge;
 
 #warn $new_re;
 	$qr = eval {
@@ -942,8 +918,6 @@ sub new_constructor {
 
 =item JE::Object
 
-=back
-
 =cut
 
 
