@@ -1,6 +1,6 @@
 package JE::Parser;
 
-our $VERSION = '0.065';
+our $VERSION = '0.54';
 
 use strict;  # :-(
 use warnings;# :-(
@@ -345,8 +345,7 @@ sub term() {
 	}
 	elsif(m-\G
 		/
-		( (?:[^/*\\[] | \\. | \[ (?>(?:[^]\\] | \\.)*) \] )
-		  (?>(?:[^/\\[] | \\. | \[ (?>(?:[^]\\] | \\.)*) \] )*) )
+		( (?:[^/*\\] | \\.) (?>(?:[^/\\] | \\.)*) )
 		/
 	  	($id_cont*)
 	      -cogx ) {
@@ -392,15 +391,8 @@ sub term() {
 				$tmp = ident
 				or defined($tmp = &str)&&$tmp=~s/^s// or
 					defined($tmp = &num)
-				or do {
-					# ECMAScript 5 allows a
-					# trailing comma
-					/\G}/cg or expected
-					 "'}', identifier, or string or ".
-					 " number literal";
-					return bless [[$pos, pos],
-					              hash => @ret], JECE;
-				};
+				or expected
+				 'identifier, or string or number literal';
 
 				push @ret, $tmp;
 				&skip;
