@@ -1,6 +1,6 @@
 package JE::Scope;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 use strict;
 use warnings; no warnings 'utf8';
@@ -58,10 +58,11 @@ sub new_var {
 sub AUTOLOAD { # This delegates the method to the global object
 	my($method) = $AUTOLOAD =~ /([^:]+)\z/;
 
-	 # deal with various ALLCAPS names
+	 # deal with DESTROY, etc. # ~~~ Am I doing the right
+	                           #     thing?
 	if($method =~ /^[A-Z]+\z/) {
 		substr($method,0,0) = 'SUPER::';
-		local *@;
+		local $@;
 		return eval { shift->$method(@_) };
 	}
 
@@ -70,8 +71,6 @@ sub AUTOLOAD { # This delegates the method to the global object
 	                         #     the call stack.
 }
 
-sub DESTROY {}
-
 1;
 
 =head1 NAME
@@ -123,8 +122,6 @@ The variable object is the first object in the scope chain
 stack) that is a call object, or C<< $scope->[0] >> if no call object is 
 found.
 
-=back
-
 =head1 CONSTRUCTOR
 
 None. Just bless an array reference. You should not need to do
@@ -133,16 +130,12 @@ classes.
 
 =head1 SEE ALSO
 
-=over
-
 =item L<JE>
 
 =item L<JE::LValue>
 
 =item L<JE::Object::Function>
 
-=back
-
 =cut
 
 
