@@ -1,6 +1,6 @@
 package JE::Undefined;
 
-our $VERSION = '0.066';
+our $VERSION = '0.54';
 
 use strict;
 use warnings;
@@ -44,7 +44,6 @@ Undefined stringifies to 'undefined', and is false as a boolean.
 
 sub new    { bless \do{my $thing = $_[1]}, $_[0] }
 sub value  { undef }
-*TO_JSON=*value;
 sub typeof { 'undefined' }
 sub id     { 'undef' }
 sub primitive { 1 }
@@ -67,4 +66,3 @@ __END__
 
 =item JE
 
-=back
